@@ -1,43 +1,31 @@
 /*
-    Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-    Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+    SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
     Refactored from earlier code by:
-    Copyright (c) 2010 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "multiplyinglineview_p.h"
 
 #include "libkdepim_debug.h"
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 
-#include <QVBoxLayout>
-#include <QTimer>
-#include <QScrollBar>
 #include <QResizeEvent>
+#include <QScrollBar>
+#include <QTimer>
+#include <QVBoxLayout>
 
 using namespace KPIM;
 
 MultiplyingLineView::MultiplyingLineView(MultiplyingLineFactory *factory, MultiplyingLineEditor *parent)
-    : QScrollArea(parent), mCurDelLine(Q_NULLPTR), mPage(new QWidget(this)), mTopLayout(new QVBoxLayout(this)), mMultiplyingLineFactory(factory),
-      mLineHeight(0), mFirstColumnWidth(0), mCompletionMode(KCompletion::CompletionNone),
-      mAutoResize(false), mDynamicSizeHint(true), mModified(false)
+    : QScrollArea(parent)
+    , mPage(new QWidget(this))
+    , mTopLayout(new QVBoxLayout(this))
+    , mMultiplyingLineFactory(factory)
 {
     setWidgetResizable(true);
     setFrameStyle(QFrame::NoFrame);
@@ -45,7 +33,7 @@ MultiplyingLineView::MultiplyingLineView(MultiplyingLineFactory *factory, Multip
     mPage->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     setWidget(mPage);
 
-    mTopLayout->setMargin(0);
+    mTopLayout->setContentsMargins(0, 0, 0, 0);
     mTopLayout->setSpacing(0);
     mPage->setLayout(mTopLayout);
 }
@@ -57,24 +45,25 @@ MultiplyingLine *MultiplyingLineView::activeLine() const
 
 MultiplyingLine *MultiplyingLineView::emptyLine() const
 {
-    foreach (MultiplyingLine *line, mLines) {
+    for (MultiplyingLine *line : std::as_const(mLines)) {
         if (line->isEmpty()) {
             return line;
         }
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
-MultiplyingLine *MultiplyingLineView::addLine()
+MultiplyingLine *MultiplyingLineView::addLine(bool showDialogBox)
 {
     const int maximumRecipients = mMultiplyingLineFactory->maximumRecipients();
     if (maximumRecipients != -1) {
         int numberOfLine = mLines.count();
         if (numberOfLine++ >= maximumRecipients) {
-            KMessageBox::sorry(this,
-                               i18n("We can not add more recipients. We have reached maximum recipients"));
+            if (showDialogBox) {
+                KMessageBox::error(this, i18n("We can not add more recipients. We have reached maximum recipients"));
+            }
 
-            return Q_NULLPTR;
+            return nullptr;
         }
     }
     MultiplyingLine *line = mMultiplyingLineFactory->newLine(widget());
@@ -82,17 +71,12 @@ MultiplyingLine *MultiplyingLineView::addLine()
     mTopLayout->addWidget(line);
     line->setCompletionMode(mCompletionMode);
     line->show();
-    connect(line, &MultiplyingLine::returnPressed,
-            this, &MultiplyingLineView::slotReturnPressed);
-    connect(line, &MultiplyingLine::upPressed,
-            this, &MultiplyingLineView::slotUpPressed);
-    connect(line, &MultiplyingLine::downPressed,
-            this, &MultiplyingLineView::slotDownPressed);
+    connect(line, &MultiplyingLine::returnPressed, this, &MultiplyingLineView::slotReturnPressed);
+    connect(line, &MultiplyingLine::upPressed, this, &MultiplyingLineView::slotUpPressed);
+    connect(line, &MultiplyingLine::downPressed, this, &MultiplyingLineView::slotDownPressed);
     connect(line, &MultiplyingLine::rightPressed, this, &MultiplyingLineView::focusRight);
-    connect(line, &MultiplyingLine::deleteLine,
-            this, &MultiplyingLineView::slotDecideLineDeletion);
-    connect(line, &MultiplyingLine::completionModeChanged,
-            this, &MultiplyingLineView::setCompletionMode);
+    connect(line, &MultiplyingLine::deleteLine, this, &MultiplyingLineView::slotDecideLineDeletion);
+    connect(line, &MultiplyingLine::completionModeChanged, this, &MultiplyingLineView::setCompletionMode);
 
     if (!mLines.isEmpty()) {
         line->fixTabOrder(mLines.last()->tabOut());
@@ -121,7 +105,10 @@ void MultiplyingLineView::slotReturnPressed(MultiplyingLine *line)
     if (!line->data()->isEmpty()) {
         MultiplyingLine *empty = emptyLine();
         if (!empty) {
-            empty = addLine();
+            empty = addLine(true);
+        }
+        if (!empty) {
+            return;
         }
         activateLine(empty);
     }
@@ -129,8 +116,8 @@ void MultiplyingLineView::slotReturnPressed(MultiplyingLine *line)
 
 void MultiplyingLineView::slotDownPressed(MultiplyingLine *line)
 {
-    int pos = mLines.indexOf(line);
-    if (pos >= (int)mLines.count() - 1) {
+    const int pos = mLines.indexOf(line);
+    if (pos >= (mLines.count() - 1)) {
         Q_EMIT focusDown();
     } else if (pos >= 0) {
         activateLine(mLines.at(pos + 1));
@@ -139,7 +126,7 @@ void MultiplyingLineView::slotDownPressed(MultiplyingLine *line)
 
 void MultiplyingLineView::slotUpPressed(MultiplyingLine *line)
 {
-    int pos = mLines.indexOf(line);
+    const int pos = mLines.indexOf(line);
     if (pos > 0) {
         activateLine(mLines.at(pos - 1));
     } else {
@@ -170,7 +157,7 @@ void MultiplyingLineView::slotDeleteLine()
 
     MultiplyingLine *line = mCurDelLine;
     line->aboutToBeDeleted();
-    int pos = mLines.indexOf(line);
+    const int pos = mLines.indexOf(line);
 
     if (mCurDelLine->isActive()) {
         int newPos;
@@ -188,7 +175,7 @@ void MultiplyingLineView::slotDeleteLine()
 
     mLines.removeAll(line);
     line->hide();
-    line->setParent(Q_NULLPTR);
+    line->setParent(nullptr);
     line->deleteLater();
 
     if (pos > 0) {
@@ -226,16 +213,17 @@ void MultiplyingLineView::activateLine(MultiplyingLine *line)
 void MultiplyingLineView::resizeEvent(QResizeEvent *ev)
 {
     QScrollArea::resizeEvent(ev);
-    for (int i = 0; i < mLines.count(); ++i) {
+    const int numberLine(mLines.count());
+    for (int i = 0; i < numberLine; ++i) {
         mLines.at(i)->resize(ev->size().width(), mLineHeight);
     }
-    ensureVisible(0, mLines.count() * mLineHeight, 0, 0);
+    ensureVisible(0, numberLine * mLineHeight, 0, 0);
 }
 
 QSize MultiplyingLineView::sizeHint() const
 {
     if (mDynamicSizeHint) {
-        return QSize(200, mLineHeight * mLines.count());
+        return {200, mLineHeight * static_cast<int>(mLines.count())};
     } else {
         return QScrollArea::sizeHint();
     }
@@ -251,7 +239,7 @@ QSize MultiplyingLineView::minimumSizeHint() const
         } else {
             height = mLineHeight * numLines;
         }
-        return QSize(200, height);
+        return {200, height};
     } else {
         return QScrollArea::minimumSizeHint();
     }
@@ -262,9 +250,8 @@ QList<MultiplyingLineData::Ptr> MultiplyingLineView::allData() const
     QList<MultiplyingLineData::Ptr> data;
 
     QListIterator<MultiplyingLine *> it(mLines);
-    MultiplyingLine *line;
     while (it.hasNext()) {
-        line = it.next();
+        MultiplyingLine *line = it.next();
         if (!line->data()->isEmpty()) {
             data.append(line->data());
         }
@@ -287,14 +274,14 @@ void MultiplyingLineView::setCompletionMode(KCompletion::CompletionMode mode)
         line->setCompletionMode(mode);
         line->blockSignals(false);
     }
-    Q_EMIT completionModeChanged(mode);   //report change to MultiplyingLineEditor
+    Q_EMIT completionModeChanged(mode); // report change to MultiplyingLineEditor
 }
 
 void MultiplyingLineView::removeData(const MultiplyingLineData::Ptr &data)
 {
     // search a line which matches recipient and type
     QListIterator<MultiplyingLine *> it(mLines);
-    MultiplyingLine *line = Q_NULLPTR;
+    MultiplyingLine *line = nullptr;
     while (it.hasNext()) {
         line = it.next();
         if (line->data() == data) {
@@ -313,7 +300,7 @@ bool MultiplyingLineView::isModified() const
     }
 
     QListIterator<MultiplyingLine *> it(mLines);
-    MultiplyingLine *line;
+    MultiplyingLine *line = nullptr;
     while (it.hasNext()) {
         line = it.next();
         if (line->isModified()) {
@@ -329,16 +316,15 @@ void MultiplyingLineView::clearModified()
     mModified = false;
 
     QListIterator<MultiplyingLine *> it(mLines);
-    MultiplyingLine *line;
     while (it.hasNext()) {
-        line = it.next();
+        MultiplyingLine *line = it.next();
         line->clearModified();
     }
 }
 
 void MultiplyingLineView::setFocus()
 {
-    if (!mLines.empty() && mLines.last()->isActive()) {
+    if (!mLines.empty() && mLines.constLast()->isActive()) {
         setFocusBottom();
     } else {
         setFocusTop();
@@ -348,7 +334,7 @@ void MultiplyingLineView::setFocus()
 void MultiplyingLineView::setFocusTop()
 {
     if (!mLines.empty()) {
-        MultiplyingLine *line = mLines.first();
+        MultiplyingLine *line = mLines.constFirst();
         if (line) {
             line->activate();
         } else {
@@ -361,7 +347,7 @@ void MultiplyingLineView::setFocusTop()
 
 void MultiplyingLineView::setFocusBottom()
 {
-    MultiplyingLine *line = mLines.last();
+    MultiplyingLine *line = mLines.constLast();
     if (line) {
         ensureWidgetVisible(line);
         line->activate();
@@ -375,9 +361,8 @@ int MultiplyingLineView::setFirstColumnWidth(int w)
     mFirstColumnWidth = w;
 
     QListIterator<MultiplyingLine *> it(mLines);
-    MultiplyingLine *line;
     while (it.hasNext()) {
-        line = it.next();
+        MultiplyingLine *line = it.next();
         mFirstColumnWidth = line->setColumnWidth(mFirstColumnWidth);
     }
 
@@ -385,7 +370,7 @@ int MultiplyingLineView::setFirstColumnWidth(int w)
     return mFirstColumnWidth;
 }
 
-QList< MultiplyingLine * > MultiplyingLineView::lines() const
+QList<MultiplyingLine *> MultiplyingLineView::lines() const
 {
     return mLines;
 }
@@ -404,7 +389,7 @@ void MultiplyingLineView::setAutoResize(bool resize)
     }
 }
 
-bool MultiplyingLineView::autoResize()
+bool MultiplyingLineView::autoResize() const
 {
     return mAutoResize;
 }
@@ -419,3 +404,4 @@ bool MultiplyingLineView::dynamicSizeHint() const
     return mDynamicSizeHint;
 }
 
+#include "moc_multiplyinglineview_p.cpp"
